#ifndef POKEPLATINUM_UNK_0202854C_H
#define POKEPLATINUM_UNK_0202854C_H

#include "struct_decls/struct_02025E6C_decl.h"
#include "struct_decls/struct_0202855C_decl.h"
#include "struct_decls/struct_02029894_decl.h"
#include "struct_decls/struct_020298B0_decl.h"
#include "struct_decls/struct_021C0794_decl.h"

int sub_0202854C(void);
int sub_02028554(void);
int sub_02028558(void);
UnkStruct_0202855C * sub_0202855C(u32 param0);
void sub_02028574(UnkStruct_020298B0 * param0);
void sub_02028658(UnkStruct_021C0794 * param0, int param1);
void sub_02028758(UnkStruct_021C0794 * param0, s32 param1, BOOL param2);
void sub_0202878C(UnkStruct_021C0794 * param0);
void sub_020287E0(UnkStruct_021C0794 * param0);
void sub_020287F8(UnkStruct_021C0794 * param0);
BOOL sub_02028810(UnkStruct_021C0794 * param0);
void sub_02028828(UnkStruct_020298B0 * param0);
void sub_02028830(UnkStruct_020298B0 * param0, const UnkStruct_02025E6C * param1);
UnkStruct_02025E6C * sub_020288C8(const UnkStruct_020298B0 * param0, int param1, int param2);
u32 sub_02028930(UnkStruct_020298B0 * param0);
int sub_02028938(int param0);
BOOL sub_0202895C(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02028984(UnkStruct_020298B0 * param0, int param1);
int sub_020289A0(UnkStruct_020298B0 * param0);
int sub_020289B8(UnkStruct_020298B0 * param0, int param1);
int sub_020289C4(UnkStruct_020298B0 * param0, int param1);
void sub_02028A10(UnkStruct_020298B0 * param0, int param1, int param2);
int sub_02028ACC(UnkStruct_020298B0 * param0, int param1, int param2);
BOOL sub_02028AFC(UnkStruct_020298B0 * param0, int param1);
void sub_02028B20(UnkStruct_020298B0 * param0, int param1);
void sub_02028B34(UnkStruct_020298B0 * param0);
int sub_02028B70(UnkStruct_020298B0 * param0);
int sub_02028B88(UnkStruct_020298B0 * param0, int param1);
int sub_02028B94(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02028BC8(UnkStruct_020298B0 * param0, int param1);
void sub_02028BE8(UnkStruct_020298B0 * param0, int param1, int param2);
int sub_02028C3C(UnkStruct_020298B0 * param0);
int sub_02028C54(UnkStruct_020298B0 * param0, int param1);
int sub_02028C60(UnkStruct_020298B0 * param0, int param1);
int sub_02028C6C(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02028CB0(UnkStruct_020298B0 * param0, int param1, int param2);
void sub_02028CD8(UnkStruct_020298B0 * param0, int param1, int param2);
int sub_02028D58(UnkStruct_020298B0 * param0);
int sub_02028D74(UnkStruct_020298B0 * param0, int param1);
int sub_02028D80(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02028DB4(UnkStruct_020298B0 * param0, int param1);
void sub_02028DD8(UnkStruct_020298B0 * param0, int param1, int param2);
int sub_02028E28(UnkStruct_020298B0 * param0);
int sub_02028E44(UnkStruct_020298B0 * param0, int param1);
int sub_02028E50(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02028E84(UnkStruct_020298B0 * param0, int param1);
void sub_02028EA8(UnkStruct_020298B0 * param0, int param1, int param2);
void sub_02028EF8(UnkStruct_020298B0 * param0, int param1, int param2, int param3, int param4);
int sub_02028F40(UnkStruct_020298B0 * param0, int param1);
int sub_02028F5C(UnkStruct_020298B0 * param0, int param1);
int sub_02028F88(UnkStruct_020298B0 * param0, int param1);
void sub_02028FB4(UnkStruct_020298B0 * param0, int param1);
void sub_02028FE0(UnkStruct_020298B0 * param0, int param1, int param2, int param3, int param4, int param5);
int sub_02029030(UnkStruct_020298B0 * param0, int param1);
int sub_0202903C(UnkStruct_020298B0 * param0, int param1);
int sub_0202905C(UnkStruct_020298B0 * param0, int param1);
int sub_0202907C(UnkStruct_020298B0 * param0, int param1);
void sub_02029088(UnkStruct_020298B0 * param0, int param1, int param2, int param3, int param4, int param5, int param6);
int sub_020290DC(UnkStruct_020298B0 * param0, int param1);
int sub_020290E8(UnkStruct_020298B0 * param0, int param1);
int sub_02029108(UnkStruct_020298B0 * param0, int param1);
int sub_02029128(UnkStruct_020298B0 * param0, int param1);
int sub_02029134(UnkStruct_020298B0 * param0, int param1);
int sub_02029140(UnkStruct_020298B0 * param0, int param1, int param2);
void sub_020291A4(UnkStruct_020298B0 * param0, int param1);
int sub_020291CC(UnkStruct_020298B0 * param0, int param1);
int sub_020291EC(UnkStruct_020298B0 * param0, int param1);
BOOL sub_0202920C(UnkStruct_020298B0 * param0);
void sub_02029220(UnkStruct_020298B0 * param0);
BOOL sub_02029234(UnkStruct_020298B0 * param0);
void sub_02029240(UnkStruct_020298B0 * param0);
void sub_02029250(UnkStruct_020298B0 * param0, int param1);
BOOL sub_02029274(UnkStruct_020298B0 * param0, int param1);
void sub_0202929C(UnkStruct_020298B0 * param0);
int sub_020292B4(UnkStruct_020298B0 * param0);
void sub_020292C0(UnkStruct_02029894 * param0);
void sub_020292CC(UnkStruct_02029894 * param0);
void sub_02029300(UnkStruct_02029894 * param0);
void sub_02029308(UnkStruct_02029894 * param0, int param1, int param2, int param3, int param4);
void sub_02029364(UnkStruct_02029894 * param0, int param1, int param2, int param3);
int sub_020293B0(const UnkStruct_02029894 * param0, int param1);
int sub_020293FC(const UnkStruct_02029894 * param0, int param1);
int sub_0202942C(const UnkStruct_02029894 * param0, int param1);
int sub_02029460(const UnkStruct_02029894 * param0);
int sub_0202948C(const UnkStruct_02029894 * param0);
int sub_020294B8(const UnkStruct_0202855C * param0);
int sub_020294C0(const UnkStruct_0202855C * param0);
void sub_020294D4(UnkStruct_0202855C * param0, int param1);
int sub_020294EC(const UnkStruct_0202855C * param0);
void sub_020294F4(UnkStruct_0202855C * param0, int param1);
int sub_02029524(const UnkStruct_0202855C * param0);
void sub_0202952C(UnkStruct_0202855C * param0);
void sub_0202955C(UnkStruct_0202855C * param0);
int sub_0202958C(const UnkStruct_0202855C * param0);
int sub_020295B8(const UnkStruct_0202855C * param0);
void sub_020295C0(UnkStruct_0202855C * param0);
int sub_020295F0(const UnkStruct_0202855C * param0);
void sub_020295F8(UnkStruct_0202855C * param0, int param1);
int sub_0202963C(const UnkStruct_0202855C * param0);
void sub_02029644(UnkStruct_0202855C * param0, int param1);
void sub_02029688(UnkStruct_0202855C * param0, int param1);
int sub_020296CC(const UnkStruct_0202855C * param0);
void sub_020296D4(UnkStruct_0202855C * param0);
int sub_02029704(const UnkStruct_0202855C * param0);
void sub_0202970C(UnkStruct_0202855C * param0);
int sub_0202973C(const UnkStruct_0202855C * param0);
void sub_02029744(UnkStruct_0202855C * param0);
int sub_02029774(const UnkStruct_0202855C * param0);
void sub_0202977C(UnkStruct_0202855C * param0);
int sub_020297AC(const UnkStruct_0202855C * param0);
void sub_020297B4(UnkStruct_0202855C * param0);
int sub_020297E4(const UnkStruct_0202855C * param0);
void sub_020297EC(UnkStruct_0202855C * param0);
int sub_0202981C(const UnkStruct_0202855C * param0);
void sub_02029824(UnkStruct_0202855C * param0);
void sub_02029854(UnkStruct_02029894 * param0, int param1, int param2, int param3);
int sub_02029874(const UnkStruct_02029894 * param0);
int sub_0202987C(const UnkStruct_02029894 * param0);
int sub_02029884(const UnkStruct_02029894 * param0);
BOOL sub_0202988C(const UnkStruct_02029894 * param0);
UnkStruct_02029894 * sub_02029894(UnkStruct_021C0794 * param0);
UnkStruct_0202855C * sub_020298A0(UnkStruct_021C0794 * param0);
UnkStruct_0202855C * sub_020298AC(UnkStruct_02029894 * param0);
UnkStruct_020298B0 * sub_020298B0(UnkStruct_021C0794 * param0);

#endif // POKEPLATINUM_UNK_0202854C_H
