#include <nitro.h>
#include <string.h>

#include "inlines.h"

#include "struct_decls/struct_020298B0_decl.h"
#include "struct_decls/struct_0203E724_decl.h"
#include "struct_decls/struct_021C0794_decl.h"

#include "struct_defs/struct_0203CDB0.h"
#include "struct_defs/struct_0203E724_t.h"

#include "unk_0202854C.h"
#include "unk_0204E974.h"

BOOL sub_0204E974 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    UnkStruct_021C0794 * v1 = v0->unk_0C;
    UnkStruct_020298B0 * v2;
    u16 v3 = inline_02049538(param0);
    u16 v4 = inline_02049538(param0);
    u16 * v5 = inline_0204FCAC(param0);

    v2 = sub_020298B0(v1);
    *v5 = sub_0202895C(v2, v3);

    return 0;
}

BOOL sub_0204E9C8 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EA04 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    UnkStruct_021C0794 * v1 = v0->unk_0C;
    UnkStruct_020298B0 * v2;
    u16 v3 = inline_02049538(param0);
    u16 v4 = inline_02049538(param0);
    u16 * v5 = inline_0204FCAC(param0);

    v2 = sub_020298B0(v1);
    *v5 = sub_02028984(v2, v3);

    return 0;
}

BOOL sub_0204EA58 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EA94 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    UnkStruct_021C0794 * v1 = v0->unk_0C;
    UnkStruct_020298B0 * v2;
    u16 v3 = inline_02049538(param0);
    u16 v4 = inline_02049538(param0);
    u16 * v5 = inline_0204FCAC(param0);

    v2 = sub_020298B0(v1);
    *v5 = sub_02028E84(v2, v3);

    return 0;
}

BOOL sub_0204EAE8 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EB24 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EB60 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EB9C (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    UnkStruct_021C0794 * v1 = v0->unk_0C;
    UnkStruct_020298B0 * v2;
    u16 v3 = inline_02049538(param0);
    u16 v4 = inline_02049538(param0);
    u16 * v5 = inline_0204FCAC(param0);

    v2 = sub_020298B0(v1);

    return 0;
}

BOOL sub_0204EBE4 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EC20 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EC5C (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204EC98 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    UnkStruct_021C0794 * v1 = v0->unk_0C;
    UnkStruct_020298B0 * v2;
    u16 v3 = inline_02049538(param0);
    u16 v4 = inline_02049538(param0);
    u16 * v5 = inline_0204FCAC(param0);

    v2 = sub_020298B0(v1);
    *v5 = sub_02028CB0(v2, v3, v4);
    return 0;
}

BOOL sub_0204ECF0 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204ED2C (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}

BOOL sub_0204ED68 (UnkStruct_0203E724 * param0)
{
    UnkStruct_0203CDB0 * v0 = param0->unk_34;
    u16 v1 = inline_02049538(param0);
    u16 v2 = inline_02049538(param0);
    u16 * v3 = inline_0204FCAC(param0);

    return 0;
}
